/*
 *    DeweyDecimalClassificationSystem.java
 *    Copyright (C) 2000 Stuart Yeates 
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

// the package we're in
package org.nzdl.gsdl.classification;

// java standard library classes used
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.Serializable;
import java.lang.Cloneable;
import java.util.Vector;
import java.util.Hashtable;
import java.util.Enumeration;
import java.util.Properties;

/**
 * The Dewey Decimal Classification System
 * 
 * @author stuart yeates (say1@cs.waikato.ac.nz)
 * @version $Revision: 2191 $
 * @see org.nzdl.gsdl.classification.Classification
 * @see org.nzdl.gsdl.classification.ClassificationSystem
 * @see org.nzdl.gsdl.classification.DeweyDecimalClassification
 * @see java.io.Serializable
 * @see java.lang.Cloneable
 */

public class DeweyDecimalClassificationSystem 
  implements ClassificationSystem {
  
  static DeweyDecimalClassificationSystem instance = null;
  
  static final protected String name = "Dewey Decimal Classification System";
  DeweyDecimalClassification root = null;
  
  protected DeweyDecimalClassificationSystem() {
    root = new DeweyDecimalClassification(this, null,0,"",getName());
    init();
    root.clean();
  }
  static public DeweyDecimalClassificationSystem getInstance() {
    if (instance == null)
      instance = new DeweyDecimalClassificationSystem();
    return instance;
  }

  protected boolean add (String key, String value) {
    return root.add(key,value);
  }
  
  protected void init() {
    add("000","Dewey Decimal Classification System --- Generalities");
    add("001","Dewey Decimal Classification System --- Generalities --- Generalities --- Knowledge");
    add("002","Dewey Decimal Classification System --- Generalities --- Generalities --- The Book");
    add("003","Dewey Decimal Classification System --- Generalities --- Generalities --- Systems");
    add("004","Dewey Decimal Classification System --- Generalities --- Generalities --- Data processing, Computer science");
    add("005","Dewey Decimal Classification System --- Generalities --- Generalities --- Computer programming, programs, data");
    add("006","Dewey Decimal Classification System --- Generalities --- Generalities --- Computer programming, programs, data --- Special computer methods");
    add("010","Dewey Decimal Classification System --- Generalities --- Bibliography");
    add("011","Dewey Decimal Classification System --- Generalities --- Bibliography --- Bibliographies");
    add("012","Dewey Decimal Classification System --- Generalities --- Bibliography --- Bibliographies of individuals");
    add("013","Dewey Decimal Classification System --- Generalities --- Bibliography --- Bibliographies of works by specific classes of authors");
    add("014","Dewey Decimal Classification System --- Generalities --- Bibliography --- Bibliographies of anonymous and pseudonymous works");
    add("015","Dewey Decimal Classification System --- Generalities --- Bibliography --- Bibliographies of works from specific places");
    add("016","Dewey Decimal Classification System --- Generalities --- Bibliography --- Bibliographies of works on specific subjects");
    add("017","Dewey Decimal Classification System --- Generalities --- Bibliography --- Subject catalogs");
    add("018","Dewey Decimal Classification System --- Generalities --- Bibliography --- Catalogs arranged by author and date");
    add("019","Dewey Decimal Classification System --- Generalities --- Bibliography --- Dictionary catalogs");
    add("020","Dewey Decimal Classification System --- Generalities --- Information science --- Library Science");
    add("021","Dewey Decimal Classification System --- Generalities --- Information science --- Libraries, relationships");
    add("022","Dewey Decimal Classification System --- Generalities --- Information science --- Libraries, administration of the physical plant");
    add("023","Dewey Decimal Classification System --- Generalities --- Information science --- Libraries, personnel administration");
    add("025","Dewey Decimal Classification System --- Generalities --- Information science --- Libraries, operations");
    add("026","Dewey Decimal Classification System --- Generalities --- Information science --- Libraries for specific subjects");
    add("027","Dewey Decimal Classification System --- Generalities --- Information science --- Libraries, general");
    add("028","Dewey Decimal Classification System --- Generalities --- Information science --- Libraries, reading and use of other information media");
    add("030","Dewey Decimal Classification System --- Generalities --- Encyclopedic works");
    add("031","Dewey Decimal Classification System --- Generalities --- Encyclopedic works --- American");
    add("032","Dewey Decimal Classification System --- Generalities --- Encyclopedic works --- in English");
    add("033","Dewey Decimal Classification System --- Generalities --- Encyclopedic works --- in other Germanic languages");
    add("034","Dewey Decimal Classification System --- Generalities --- Encyclopedic works --- in French, Provencal, Catalon");
    add("035","Dewey Decimal Classification System --- Generalities --- Encyclopedic works --- in Italian, Romanian, Rhaeto-Romanic");
    add("036","Dewey Decimal Classification System --- Generalities --- Encyclopedic works --- in Spanish & Portuguese");
    add("037","Dewey Decimal Classification System --- Generalities --- Encyclopedic works --- in Slavic Languages");
    add("038","Dewey Decimal Classification System --- Generalities --- Encyclopedic works --- in Scandinavian languages");
    add("039","Dewey Decimal Classification System --- Generalities --- Encyclopedic works --- in other languages");
    add("050","Dewey Decimal Classification System --- Generalities --- Serials");
    add("051","Dewey Decimal Classification System --- Generalities --- Serials --- American");
    add("052","Dewey Decimal Classification System --- Generalities --- Serials --- in English");
    add("053","Dewey Decimal Classification System --- Generalities --- Serials --- in other Germanic languages");
    add("054","Dewey Decimal Classification System --- Generalities --- Serials --- in French, Provencal, Catalon");
    add("055","Dewey Decimal Classification System --- Generalities --- Serials --- in Italian, Romanian, Rhaeto-Romanic");
    add("056","Dewey Decimal Classification System --- Generalities --- Serials --- in Spanish & Portuguese");
    add("057","Dewey Decimal Classification System --- Generalities --- Serials --- in Slavic Languages");
    add("058","Dewey Decimal Classification System --- Generalities --- Serials --- in Scandinavian languages");
    add("059","Dewey Decimal Classification System --- Generalities --- Serials --- in other languages");
    add("060","Dewey Decimal Classification System --- Generalities --- Organizations & Museology");
    add("061","Dewey Decimal Classification System --- Generalities --- Organizations & Museology --- in North America");
    add("062","Dewey Decimal Classification System --- Generalities --- Organizations & Museology --- in British Isles; in England");
    add("063","Dewey Decimal Classification System --- Generalities --- Organizations & Museology --- in central Europe; in Germany");
    add("064","Dewey Decimal Classification System --- Generalities --- Organizations & Museology --- in France & Monaco");
    add("065","Dewey Decimal Classification System --- Generalities --- Organizations & Museology --- in Italy & adjacent territories");
    add("066","Dewey Decimal Classification System --- Generalities --- Organizations & Museology --- in Iberian Peninsula & adjacent islands");
    add("067","Dewey Decimal Classification System --- Generalities --- Organizations & Museology --- in eastern Europe; in Soviet Union");
    add("068","Dewey Decimal Classification System --- Generalities --- Organizations & Museology --- in other areas");
    add("069","Dewey Decimal Classification System --- Generalities --- Organizations & Museology --- Museology & Museum science");
    add("070","Dewey Decimal Classification System --- Generalities --- News media & Journalism");
    add("071","Dewey Decimal Classification System --- Generalities --- News media & Journalism --- in North America");
    add("072","Dewey Decimal Classification System --- Generalities --- News media & Journalism --- in British Isles; in England");
    add("073","Dewey Decimal Classification System --- Generalities --- News media & Journalism --- in central Europe; in Germany");
    add("074","Dewey Decimal Classification System --- Generalities --- News media & Journalism --- in France & Monaco");
    add("075","Dewey Decimal Classification System --- Generalities --- News media & Journalism --- in Italy & adjacent territories");
    add("076","Dewey Decimal Classification System --- Generalities --- News media & Journalism --- in Iberian Peninsula & adjacent islands");
    add("077","Dewey Decimal Classification System --- Generalities --- News media & Journalism --- in eastern Europe; in Soviet Union");
    add("078","Dewey Decimal Classification System --- Generalities --- News media & Journalism --- in Scandinavia");
    add("079","Dewey Decimal Classification System --- Generalities --- News media & Journalism --- in other areas");
    add("080","Dewey Decimal Classification System --- Generalities --- Collections");
    add("081","Dewey Decimal Classification System --- Generalities --- Collections --- American");
    add("082","Dewey Decimal Classification System --- Generalities --- Collections --- In English");
    add("083","Dewey Decimal Classification System --- Generalities --- Collections --- In other Germanic languages");
    add("084","Dewey Decimal Classification System --- Generalities --- Collections --- In French, Provencal, Catalon");
    add("085","Dewey Decimal Classification System --- Generalities --- Collections --- In Italian, Romanian, Rhaeto-Romanic");
    add("086","Dewey Decimal Classification System --- Generalities --- Collections --- In Spanish & Portuguese");
    add("087","Dewey Decimal Classification System --- Generalities --- Collections --- In Slavic Languages");
    add("088","Dewey Decimal Classification System --- Generalities --- Collections --- In Scandinavian languages");
    add("089","Dewey Decimal Classification System --- Generalities --- Collections --- In other languages");
    add("090","Dewey Decimal Classification System --- Generalities --- Rare books");
    add("091","Dewey Decimal Classification System --- Generalities --- Rare books --- Manuscripts");
    add("092","Dewey Decimal Classification System --- Generalities --- Rare books --- Block books");
    add("098","Dewey Decimal Classification System --- Generalities --- Rare books --- Forgeries");
    add("099","Dewey Decimal Classification System --- Generalities --- Rare books --- Books notable for format");
    add("100","Dewey Decimal Classification System --- Philosophy & Psychology --- Philosophy");
    add("101","Dewey Decimal Classification System --- Philosophy & Psychology --- Philosophy--- Theory of philosophy");
    add("102","Dewey Decimal Classification System --- Philosophy & Psychology --- Philosophy--- Miscellany");
    add("103","Dewey Decimal Classification System --- Philosophy & Psychology --- Philosophy--- Dictionaries");
    add("105","Dewey Decimal Classification System --- Philosophy & Psychology --- Philosophy--- Serial publications");
    add("106","Dewey Decimal Classification System --- Philosophy & Psychology --- Philosophy--- Organizations");
    add("107","Dewey Decimal Classification System --- Philosophy & Psychology --- Philosophy--- Education and research");
    add("108","Dewey Decimal Classification System --- Philosophy & Psychology --- Philosophy--- Kinds of persons");
    add("109","Dewey Decimal Classification System --- Philosophy & Psychology --- Philosophy--- Historical treatment");
    add("110","Dewey Decimal Classification System --- Philosophy & Psychology --- Metaphysics");
    add("111","Dewey Decimal Classification System --- Philosophy & Psychology --- Metaphysics --- Ontology");
    add("113","Dewey Decimal Classification System --- Philosophy & Psychology --- Metaphysics --- Cosmology");
    add("114","Dewey Decimal Classification System --- Philosophy & Psychology --- Metaphysics --- Space");
    add("115","Dewey Decimal Classification System --- Philosophy & Psychology --- Metaphysics --- Time");
    add("116","Dewey Decimal Classification System --- Philosophy & Psychology --- Metaphysics --- Change");
    add("117","Dewey Decimal Classification System --- Philosophy & Psychology --- Metaphysics --- Structure");
    add("118","Dewey Decimal Classification System --- Philosophy & Psychology --- Metaphysics --- Energy & Force");
    add("119","Dewey Decimal Classification System --- Philosophy & Psychology --- Metaphysics --- Number & Quantity");
    add("120","Dewey Decimal Classification System --- Philosophy & Psychology --- Epistemology, Causation, Humankind");
    add("121","Dewey Decimal Classification System --- Philosophy & Psychology --- Epistemology, Causation, Humankind --- Epistemology");
    add("122","Dewey Decimal Classification System --- Philosophy & Psychology --- Epistemology, Causation, Humankind --- Causation");
    add("123","Dewey Decimal Classification System --- Philosophy & Psychology --- Epistemology, Causation, Humankind --- Determinism & Indeterminism");
    add("124","Dewey Decimal Classification System --- Philosophy & Psychology --- Epistemology, Causation, Humankind --- Teleogy");
    add("126","Dewey Decimal Classification System --- Philosophy & Psychology --- Epistemology, Causation, Humankind --- Self & Subconscious");
    add("128","Dewey Decimal Classification System --- Philosophy & Psychology --- Epistemology, Causation, Humankind --- Humankind");
    add("129","Dewey Decimal Classification System --- Philosophy & Psychology --- Epistemology, Causation, Humankind --- Origin and destiny of souls");
    add("130","Dewey Decimal Classification System --- Philosophy & Psychology --- Paranormal phenomena");
    add("131","Dewey Decimal Classification System --- Philosophy & Psychology --- Paranormal phenomena --- Occult methods for achieving well-being");
    add("133","Dewey Decimal Classification System --- Philosophy & Psychology --- Paranormal phenomena --- Occultism & Parapsychology");
    add("135","Dewey Decimal Classification System --- Philosophy & Psychology --- Paranormal phenomena --- Dreams");
    add("136","Dewey Decimal Classification System --- Philosophy & Psychology --- Paranormal phenomena --- Mysteries");
    add("137","Dewey Decimal Classification System --- Philosophy & Psychology --- Paranormal phenomena --- Graphology, divinatory");
    add("138","Dewey Decimal Classification System --- Philosophy & Psychology --- Paranormal phenomena --- Physiognomy");
    add("139","Dewey Decimal Classification System --- Philosophy & Psychology --- Paranormal phenomena --- Phrenology");
    add("140","Dewey Decimal Classification System --- Philosophy & Psychology --- Specific philosophical schools");
    add("141","Dewey Decimal Classification System --- Philosophy & Psychology --- Specific philosophical schools --- Idealism");
    add("142","Dewey Decimal Classification System --- Philosophy & Psychology --- Specific philosophical schools --- Critical philosophy");
    add("143","Dewey Decimal Classification System --- Philosophy & Psychology --- Specific philosophical schools --- Bergsonism &Intuitionism");
    add("144","Dewey Decimal Classification System --- Philosophy & Psychology --- Specific philosophical schools --- Humanism");
    add("145","Dewey Decimal Classification System --- Philosophy & Psychology --- Specific philosophical schools --- Sensationalism");
    add("146","Dewey Decimal Classification System --- Philosophy & Psychology --- Specific philosophical schools --- Naturalism");
    add("147","Dewey Decimal Classification System --- Philosophy & Psychology --- Specific philosophical schools --- Pantheism");
    add("148","Dewey Decimal Classification System --- Philosophy & Psychology --- Specific philosophical schools --- Eclecticism, Liberalism, Traditionalism");
    add("149","Dewey Decimal Classification System --- Philosophy & Psychology --- Specific philosophical schools --- Philosophical systems, other philosophical schools");
    add("150","Dewey Decimal Classification System --- Philosophy & Psychology --- Psychology");
    add("152","Dewey Decimal Classification System --- Philosophy & Psychology --- Psychology --- Emotions, Movement, Perception & Psychological drives");
    add("153","Dewey Decimal Classification System --- Philosophy & Psychology --- Psychology --- Mental processes & Intelligence");
    add("154","Dewey Decimal Classification System --- Philosophy & Psychology --- Psychology --- Subconscious");
    add("155","Dewey Decimal Classification System --- Philosophy & Psychology --- Psychology --- Developmental & Differential");
    add("156","Dewey Decimal Classification System --- Philosophy & Psychology --- Psychology --- Comparative");
    add("158","Dewey Decimal Classification System --- Philosophy & Psychology --- Psychology --- Applied");
    add("160","Dewey Decimal Classification System --- Philosophy & Psychology --- Logic");
    add("161","Dewey Decimal Classification System --- Philosophy & Psychology --- Logic --- Induction");
    add("162","Dewey Decimal Classification System --- Philosophy & Psychology --- Logic --- Deduction");
    add("165","Dewey Decimal Classification System --- Philosophy & Psychology --- Logic --- Fallacies");
    add("166","Dewey Decimal Classification System --- Philosophy & Psychology --- Logic --- Syllogisms");
    add("167","Dewey Decimal Classification System --- Philosophy & Psychology --- Logic --- Hypotheses");
    add("168","Dewey Decimal Classification System --- Philosophy & Psychology --- Logic --- Argument & Persuasion");
    add("169","Dewey Decimal Classification System --- Philosophy & Psychology --- Logic --- Analogy");
    add("170","Dewey Decimal Classification System --- Philosophy & Psychology --- Ethics");
    add("171","Dewey Decimal Classification System --- Philosophy & Psychology --- Ethics --- Ethical Systems &  Doctrines");
    add("172","Dewey Decimal Classification System --- Philosophy & Psychology --- Ethics --- Politcial ethics");
    add("173","Dewey Decimal Classification System --- Philosophy & Psychology --- Ethics --- Ethics of family relationships");
    add("174","Dewey Decimal Classification System --- Philosophy & Psychology --- Ethics --- Economic ethics& Porofessional ethics");
    add("175","Dewey Decimal Classification System --- Philosophy & Psychology --- Ethics --- Ethics, of recreation & leisure");
    add("176","Dewey Decimal Classification System --- Philosophy & Psychology --- Ethics --- Ethics, of sex & reproduction");
    add("177","Dewey Decimal Classification System --- Philosophy & Psychology --- Ethics --- Ethics, of social relations");
    add("178","Dewey Decimal Classification System --- Philosophy & Psychology --- Ethics --- Ethics, of consumption");
    add("179","Dewey Decimal Classification System --- Philosophy & Psychology --- Ethics --- Ethical norms, other");
    add("180","Dewey Decimal Classification System --- Philosophy & Psychology --- Ancient, Mediaeval & Oriental Philosophy");
    add("182","Dewey Decimal Classification System --- Philosophy & Psychology --- Ancient, Mediaeval & Oriental philosophy --- Pre-Socratic Greek philosophies");
    add("183","Dewey Decimal Classification System --- Philosophy & Psychology --- Ancient, Mediaeval & Oriental philosophy --- Sophistic & Socratic philosophies");
    add("184","Dewey Decimal Classification System --- Philosophy & Psychology --- Ancient, mediaeval & Oriental philosophy --- Platonic philosophy");
    add("185","Dewey Decimal Classification System --- Philosophy & Psychology --- Ancient, Mediaeval & Oriental philosophy --- Aristotelian philosophy");
    add("186","Dewey Decimal Classification System --- Philosophy & Psychology --- Ancient, Mediaeval & Oriental philosophy --- Neoplatonic & Skeptic philosophies");
    add("187","Dewey Decimal Classification System --- Philosophy & Psychology --- Ancient, Mediaeval & Oriental philosophy --- Epicurean philosophy");
    add("188","Dewey Decimal Classification System --- Philosophy & Psychology --- Ancient, Mediaeval & Oriental philosophy --- Stoic philosophy");
    add("189","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western");
    add("190","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western --- Modern Western");
    add("191","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western --- United States & Canada");
    add("192","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western --- British Isles");
    add("193","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western --- Germany & Austria");
    add("194","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western --- France");
    add("195","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western --- Italy");
    add("196","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western --- Spain & Portugal");
    add("197","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western --- Soviet Union");
    add("198","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western --- Scandinavia");
    add("199","Dewey Decimal Classification System --- Philosophy & Psychology --- Medieval Western --- Other geographical areas");
    add("200","Dewey Decimal Classification System --- Religion --- Religion");
    add("201","Dewey Decimal Classification System --- Religion --- Christianity --- Philosophy");
    add("202","Dewey Decimal Classification System --- Religion --- Christianity --- Miscellany");
    add("203","Dewey Decimal Classification System --- Religion --- Christianity --- Dictionaries");
    add("204","Dewey Decimal Classification System --- Religion --- Christianity --- Special topics");
    add("205","Dewey Decimal Classification System --- Religion --- Christianity --- Serial publications");
    add("206","Dewey Decimal Classification System --- Religion --- Christianity --- Organizations");
    add("207","Dewey Decimal Classification System --- Religion --- Christianity --- Education research in");
    add("208","Dewey Decimal Classification System --- Religion --- Christianity --- Kinds of persons in Christianity");
    add("209","Dewey Decimal Classification System --- Religion --- Christianity --- History & geography");
    add("210","Dewey Decimal Classification System --- Religion --- Natural Theology");
    add("211","Dewey Decimal Classification System --- Religion --- Natural Theology --- God, Concepts of");
    add("212","Dewey Decimal Classification System --- Religion --- Natural Theology --- Existence, attributes of God");
    add("213","Dewey Decimal Classification System --- Religion --- Natural Theology --- Creation");
    add("214","Dewey Decimal Classification System --- Religion --- Natural Theology --- Theodicy");
    add("215","Dewey Decimal Classification System --- Religion --- Natural Theology --- Science & religion");
    add("216","Dewey Decimal Classification System --- Religion --- Natural Theology --- Good & evil");
    add("218","Dewey Decimal Classification System --- Religion --- Natural Theology --- Humankind");
    add("220","Dewey Decimal Classification System --- Religion --- The (Christian) Bible");
    add("221","Dewey Decimal Classification System --- Religion --- The (Christian) Bible --- Old Testament");
    add("222","Dewey Decimal Classification System --- Religion --- The (Christian) Bible --- Old Testament, Historical books of");
    add("223","Dewey Decimal Classification System --- Religion --- The (Christian) Bible --- Old Testament, Poetic books of");
    add("224","Dewey Decimal Classification System --- Religion --- The (Christian) Bible --- Old Testament, Prophetic books of");
    add("225","Dewey Decimal Classification System --- Religion --- The (Christian) Bible --- New Testament");
    add("226","Dewey Decimal Classification System --- Religion --- The (Christian) Bible --- Acts & Gospels");
    add("227","Dewey Decimal Classification System --- Religion --- The (Christian) Bible --- Epistles");
    add("228","Dewey Decimal Classification System --- Religion --- The (Christian) Bible --- Apocalypse & Revelation");
    add("229","Dewey Decimal Classification System --- Religion --- The (Christian) Bible --- Apocrypha & Pseudepigrapha");
    add("230","Dewey Decimal Classification System --- Religion --- Christian theology");
    add("231","Dewey Decimal Classification System --- Religion --- Christian theology --- God");
    add("232","Dewey Decimal Classification System --- Religion --- Christian theology --- Jesus Christ & his family");
    add("233","Dewey Decimal Classification System --- Religion --- Christian theology --- Humankind");
    add("234","Dewey Decimal Classification System --- Religion --- Christian theology --- Salvation, Soteriology & Grace");
    add("235","Dewey Decimal Classification System --- Religion --- Christian theology --- Spiritual beings");
    add("236","Dewey Decimal Classification System --- Religion --- Christian theology --- Eschatology");
    add("238","Dewey Decimal Classification System --- Religion --- Christian theology --- Creeds & catechisms");
    add("239","Dewey Decimal Classification System --- Religion --- Christian theology --- Apologetics & Polemics");
    add("240","Dewey Decimal Classification System --- Religion --- Christian Devotional & Moral Theology");
    add("241","Dewey Decimal Classification System --- Religion --- Christian Devotional & Moral Theology --- Theology, Moral");
    add("242","Dewey Decimal Classification System --- Religion --- Christian Devotional & Moral Theology --- Devotional literature");
    add("243","Dewey Decimal Classification System --- Religion --- Christian Devotional & Moral Theology --- Evangelistic writings for individuals");
    add("245","Dewey Decimal Classification System --- Religion --- Christian Devotional & Moral Theology --- Hymns, Texts of");
    add("246","Dewey Decimal Classification System --- Religion --- Christian Devotional & Moral Theology --- Christianity, Use of art in");
    add("247","Dewey Decimal Classification System --- Religion --- Christian Devotional & Moral Theology --- Church furnishings & articles");
    add("248","Dewey Decimal Classification System --- Religion --- Christian Devotional & Moral Theology --- Christian experience, practice, life");
    add("249","Dewey Decimal Classification System --- Religion --- Christian Devotional & Moral Theology --- Christian observances in family life");
    add("250","Dewey Decimal Classification System --- Religion --- Christian Orders & Local Churches");
    add("251","Dewey Decimal Classification System --- Religion --- Christian Orders & Local Churches --- Homiletics & Preaching");
    add("252","Dewey Decimal Classification System --- Religion --- Christian Orders & Local Churches --- Texts of Sermons");
    add("253","Dewey Decimal Classification System --- Religion --- Christian Orders & Local Churches --- Pastoral office (Pastoral theology)");
    add("254","Dewey Decimal Classification System --- Religion --- Christian Orders & Local Churches --- Parish goverment & administration");
    add("255","Dewey Decimal Classification System --- Religion --- Christian Orders & Local Churches --- Religious congregations & orders");
    add("259","Dewey Decimal Classification System --- Religion --- Christian Orders & Local Churches --- Church, Activities of the local");
    add("260","Dewey Decimal Classification System --- Religion --- Christian Social Theology");
    add("261","Dewey Decimal Classification System --- Religion --- Christian Social Theology --- Social Theology");
    add("262","Dewey Decimal Classification System --- Religion --- Christian Social Theology --- Ecclesiology");
    add("263","Dewey Decimal Classification System --- Religion --- Christian Social Theology --- Religious observance, Times, places of");
    add("264","Dewey Decimal Classification System --- Religion --- Christian Social Theology --- Public Worship");
    add("265","Dewey Decimal Classification System --- Religion --- Christian Social Theology --- Sacraments, other rites & acts");
    add("266","Dewey Decimal Classification System --- Religion --- Christian Social Theology --- Missions");
    add("267","Dewey Decimal Classification System --- Religion --- Christian Social Theology --- Religious work, Associations for");
    add("268","Dewey Decimal Classification System --- Religion --- Christian Social Theology --- Religious education");
    add("269","Dewey Decimal Classification System --- Religion --- Christian Social Theology --- Spiritual renewal");
    add("270","Dewey Decimal Classification System --- Religion --- Christian Church History");
    add("271","Dewey Decimal Classification System --- Religion --- Christian Church History --- Church history, Religious orders in");
    add("272","Dewey Decimal Classification System --- Religion --- Christian Church History --- Church history, Persecutions in");
    add("273","Dewey Decimal Classification System --- Religion --- Christian Church History --- Church history, Heresies in");
    add("274","Dewey Decimal Classification System --- Religion --- Christian Church History --- Christian church in Europe");
    add("275","Dewey Decimal Classification System --- Religion --- Christian Church History --- Christian church in Asia");
    add("276","Dewey Decimal Classification System --- Religion --- Christian Church History --- Christian church in Africa");
    add("277","Dewey Decimal Classification System --- Religion --- Christian Church History --- Christian church in North America");
    add("278","Dewey Decimal Classification System --- Religion --- Christian Church History --- Christian church in South America");
    add("279","Dewey Decimal Classification System --- Religion --- Christian Church History --- Christian church in other areas");
    add("280","Dewey Decimal Classification System --- Religion --- Christian Denominations & Sects");
    add("281","Dewey Decimal Classification System --- Religion --- Christian Denominations & Sects --- Early church & Eastern churches");
    add("282","Dewey Decimal Classification System --- Religion --- Christian Denominations & Sects --- Roman Catholic Church");
    add("283","Dewey Decimal Classification System --- Religion --- Christian Denominations & Sects --- Anglican churches");
    add("284","Dewey Decimal Classification System --- Religion --- Christian Denominations & Sects --- Protestants of Continental origin");
    add("285","Dewey Decimal Classification System --- Religion --- Christian Denominations & Sects --- Congregational Church, Presbyterian Church & Reformed Church");
    add("286","Dewey Decimal Classification System --- Religion --- Christian Denominations & Sects --- Adventist Church, Baptist Church & Disciples of Christ Church");
    add("287","Dewey Decimal Classification System --- Religion --- Christian Denominations & Sects --- Methodist Churches & Salvation Army");
    add("289","Dewey Decimal Classification System --- Religion --- Christian Denominations & Sects --- Denominations & sects, other");
    add("290","Dewey Decimal Classification System --- Religion --- Religions, Comparative and Other");
    add("291","Dewey Decimal Classification System --- Religion --- Religions, Comparative and Other --- Religion, comparative");
    add("292","Dewey Decimal Classification System --- Religion --- Religions, Comparative and Other --- Religion, Classical (Greek & Roman)");
    add("293","Dewey Decimal Classification System --- Religion --- Religions, Comparative and Other --- Religion, Germanic");
    add("294","Dewey Decimal Classification System --- Religion --- Religions, Comparative and Other --- Religions of Indic origin");
    add("295","Dewey Decimal Classification System --- Religion --- Religions, Comparative and Other --- Mazdaism & Parseeism &  Zoroastrianism");
    add("296","Dewey Decimal Classification System --- Religion --- Religions, Comparative and Other --- Judaism");
    add("297","Dewey Decimal Classification System --- Religion --- Religions, Comparative and Other --- Islam & religions originating in it");
    add("299","Dewey Decimal Classification System --- Religion --- Religions, Comparative and Other --- Religions, other");
    add("300","Dewey Decimal Classification System --- Social Sciences");
    add("301","Dewey Decimal Classification System --- Social Sciences --- Social Science --- Anthropology & Sociology");
    add("302","Dewey Decimal Classification System --- Social Sciences --- Social Science --- Social interaction");
    add("303","Dewey Decimal Classification System --- Social Sciences --- Social Science --- Social processes");
    add("304","Dewey Decimal Classification System --- Social Sciences --- Social Science --- Social behavior, Factors affecting");
    add("305","Dewey Decimal Classification System --- Social Sciences --- Social Science --- Social groups");
    add("306","Dewey Decimal Classification System --- Social Sciences --- Social Science --- Culture & Institutions");
    add("307","Dewey Decimal Classification System --- Social Sciences --- Social Science --- Communities");
    add("310","Dewey Decimal Classification System --- Social Sciences --- Statistics --- Statistics");
    add("314","Dewey Decimal Classification System --- Social Sciences --- Statistics --- Statistics of Europe");
    add("315","Dewey Decimal Classification System --- Social Sciences --- Statistics --- Statistics of Asia");
    add("316","Dewey Decimal Classification System --- Social Sciences --- Statistics --- Statistics of Africa");
    add("317","Dewey Decimal Classification System --- Social Sciences --- Statistics --- Statistics of North America");
    add("318","Dewey Decimal Classification System --- Social Sciences --- Statistics --- Statistics of South America");
    add("319","Dewey Decimal Classification System --- Social Sciences --- Statistics --- Statistics of other parts of the world");
    add("320","Dewey Decimal Classification System --- Social Sciences --- Political science");
    add("321","Dewey Decimal Classification System --- Social Sciences --- Political science --- Governments & states, Systems of");
    add("322","Dewey Decimal Classification System --- Social Sciences --- Political science --- State, relation to organized groups");
    add("323","Dewey Decimal Classification System --- Social Sciences --- Political science --- Rights, Civil & political");
    add("324","Dewey Decimal Classification System --- Social Sciences --- Political science --- Political process");
    add("325","Dewey Decimal Classification System --- Social Sciences --- Political science --- Colonization & Migration, International");
    add("326","Dewey Decimal Classification System --- Social Sciences --- Political science --- Emancipation & Slavery");
    add("327","Dewey Decimal Classification System --- Social Sciences --- Political science --- International relations");
    add("328","Dewey Decimal Classification System --- Social Sciences --- Political science --- Legislative process");
    add("330","Dewey Decimal Classification System --- Social Sciences --- Economics");
    add("331","Dewey Decimal Classification System --- Social Sciences --- Economics --- Labor economics");
    add("332","Dewey Decimal Classification System --- Social Sciences --- Economics --- Financial economics");
    add("333","Dewey Decimal Classification System --- Social Sciences --- Economics --- Land economics");
    add("334","Dewey Decimal Classification System --- Social Sciences --- Economics --- Cooperatives");
    add("335","Dewey Decimal Classification System --- Social Sciences --- Economics --- Socialism & related systems");
    add("336","Dewey Decimal Classification System --- Social Sciences --- Economics --- Public finance");
    add("337","Dewey Decimal Classification System --- Social Sciences --- Economics --- International economics");
    add("338","Dewey Decimal Classification System --- Social Sciences --- Economics --- Production");
    add("339","Dewey Decimal Classification System --- Social Sciences --- Economics --- Macroeconomics");
    add("340","Dewey Decimal Classification System --- Social Sciences --- Law");
    add("341","Dewey Decimal Classification System --- Social Sciences --- Law --- International Law");
    add("342","Dewey Decimal Classification System --- Social Sciences --- Law --- Constitutional & Administrative  Law");
    add("343","Dewey Decimal Classification System --- Social Sciences --- Law --- Industrial, Military & Tax Law");
    add("344","Dewey Decimal Classification System --- Social Sciences --- Law --- Social, Labor & Welfare Law");
    add("345","Dewey Decimal Classification System --- Social Sciences --- Law --- Criminal Law");
    add("346","Dewey Decimal Classification System --- Social Sciences --- Law --- Private Law");
    add("347","Dewey Decimal Classification System --- Social Sciences --- Law --- Civil courts & procedure");
    add("348","Dewey Decimal Classification System --- Social Sciences --- Law --- Cases, Laws & Regulations");
    add("349","Dewey Decimal Classification System --- Social Sciences --- Law --- Laws of specific jurisdictions & areas");
    add("350","Dewey Decimal Classification System --- Social Sciences --- Public administration");
    add("351","Dewey Decimal Classification System --- Social Sciences --- Public administration --- Public administration of central governments");
    add("352","Dewey Decimal Classification System --- Social Sciences --- Public administration --- Public administration of local governments");
    add("353","Dewey Decimal Classification System --- Social Sciences --- Public administration --- Public administration of U.S. federal & state governments");
    add("354","Dewey Decimal Classification System --- Social Sciences --- Public administration --- Public administration of specific central governments");
    add("355","Dewey Decimal Classification System --- Social Sciences --- Public administration --- Military science");
    add("356","Dewey Decimal Classification System --- Social Sciences --- Public administration --- Foot Forces & Warfare");
    add("357","Dewey Decimal Classification System --- Social Sciences --- Public administration --- Mounted Forces & Warfare");
    add("358","Dewey Decimal Classification System --- Social Sciences --- Public administration --- Specialized Forces & Warfare");
    add("359","Dewey Decimal Classification System --- Social Sciences --- Public administration --- Navel Force & Warfare");
    add("360","Dewey Decimal Classification System --- Social Sciences --- Social services & Associations");
    add("361","Dewey Decimal Classification System --- Social Sciences --- Social services & Associations --- Social problems");
    add("362","Dewey Decimal Classification System --- Social Sciences --- Social services & Associations --- Welfare, Social");
    add("363","Dewey Decimal Classification System --- Social Sciences --- Social services & Associations --- Social problems & services, Other");
    add("364","Dewey Decimal Classification System --- Social Sciences --- Social services & Associations --- Criminology");
    add("365","Dewey Decimal Classification System --- Social Sciences --- Social services & Associations --- Social Sciences --- Penal institutions");
    add("366","Dewey Decimal Classification System --- Social Sciences --- Social services & Associations --- Association");
    add("367","Dewey Decimal Classification System --- Social Sciences --- Social services & Associations --- Clubs");
    add("368","Dewey Decimal Classification System --- Social Sciences --- Social services & Associations --- Insurance");
    add("369","Dewey Decimal Classification System --- Social Sciences --- Social services & Associations --- Associations, Miscellaneous kinds of");
    add("370","Dewey Decimal Classification System --- Social Sciences --- Education");
    add("371","Dewey Decimal Classification System --- Social Sciences --- Education --- School management & Special education");
    add("372","Dewey Decimal Classification System --- Social Sciences --- Education --- Education, Elementary");
    add("373","Dewey Decimal Classification System --- Social Sciences --- Education --- Education, Secondary");
    add("374","Dewey Decimal Classification System --- Social Sciences --- Education --- Education, Adult");
    add("375","Dewey Decimal Classification System --- Social Sciences --- Education --- Curricula");
    add("376","Dewey Decimal Classification System --- Social Sciences --- Education --- Education, of women");
    add("377","Dewey Decimal Classification System --- Social Sciences --- Education --- Schools & religion");
   add("378","Dewey Decimal Classification System --- Social Sciences --- Education --- Education, Higher");
    add("379","Dewey Decimal Classification System --- Social Sciences --- Education --- Education, and Government");
    add("380","Dewey Decimal Classification System --- Social Sciences --- Commerce, Communications and Transport");
    add("381","Dewey Decimal Classification System --- Social Sciences --- Commerce, Communications and Transport --- Internal Commerce & Domestic Trade");
    add("382","Dewey Decimal Classification System --- Social Sciences --- Commerce, Communications and Transport --- International Commerce & Foreign Trade");
    add("383","Dewey Decimal Classification System --- Social Sciences --- Commerce, Communications and Transport --- Communications, Postal");
    add("384","Dewey Decimal Classification System --- Social Sciences --- Commerce, Communications and Transport --- Communications & Telecommunications");
    add("385","Dewey Decimal Classification System --- Social Sciences --- Commerce, Communications and Transport --- Transportation, Railroad");
    add("386","Dewey Decimal Classification System --- Social Sciences --- Commerce, Communications and Transport --- Ferry & Inland waterway");
    add("387","Dewey Decimal Classification System --- Social Sciences --- Commerce, Communications and Transport --- Transportation, Water, water & space");
    add("388","Dewey Decimal Classification System --- Social Sciences --- Commerce, Communications and Transport --- Transportation, Ground");
    add("389","Dewey Decimal Classification System --- Social Sciences --- Commerce, Communications and Transport --- Metrology & Standardization");
    add("390","Dewey Decimal Classification System --- Social Sciences --- Customs & Etiquette & Folklore");
    add("391","Dewey Decimal Classification System --- Social Sciences --- Customs & Etiquette & Folklore --- Costume & Personal appearance");
    add("392","Dewey Decimal Classification System --- Social Sciences --- Customs & Etiquette & Folklore --- Customs, of life cycle & domestic life");
    add("393","Dewey Decimal Classification System --- Social Sciences --- Customs & Etiquette & Folklore --- Customs, of Death");
    add("394","Dewey Decimal Classification System --- Social Sciences --- Customs & Etiquette & Folklore --- Customs, General");
    add("398","Dewey Decimal Classification System --- Social Sciences --- Customs & Etiquette & Folklore --- Folklore");
    add("399","Dewey Decimal Classification System --- Social Sciences --- Customs & Etiquette & Folklore --- Customs, of war & diplomacy");
    add("400","Dewey Decimal Classification System --- Language");
    add("401","Dewey Decimal Classification System --- Language --- Language --- Philosophy & theory");
    add("402","Dewey Decimal Classification System --- Language --- Language --- Miscellany");
    add("403","Dewey Decimal Classification System --- Language --- Language --- Dictionaries & encyclopedias");
    add("404","Dewey Decimal Classification System --- Language --- Language --- Special topics");
    add("405","Dewey Decimal Classification System --- Language --- Language --- Serial publications");
    add("406","Dewey Decimal Classification System --- Language --- Language --- Organizations & management");
    add("407","Dewey Decimal Classification System --- Language --- Language --- Education, research, related topics");
    add("408","Dewey Decimal Classification System --- Language --- Language --- Treatment of with respect to kinds of persons");
    add("409","Dewey Decimal Classification System --- Language --- Language --- Geographical & persons treatment");
    add("410","Dewey Decimal Classification System --- Language --- Linguistics --- Linguistics");
    add("411","Dewey Decimal Classification System --- Language --- Linguistics --- Writing systems");
    add("412","Dewey Decimal Classification System --- Language --- Linguistics --- Etymology");
    add("413","Dewey Decimal Classification System --- Language --- Linguistics --- Dictionaries");
    add("414","Dewey Decimal Classification System --- Language --- Linguistics --- Phonology");
    add("415","Dewey Decimal Classification System --- Language --- Linguistics --- Language, Structural systems (Grammar)");
    add("417","Dewey Decimal Classification System --- Language --- Linguistics --- Dialectology & Historical Linguistics");
    add("418","Dewey Decimal Classification System --- Language --- Linguistics --- Standard usage & Applied Linguistics");
    add("419","Dewey Decimal Classification System --- Language --- Linguistics --- Language, Verbal, not spoken or written");
    add("420","Dewey Decimal Classification System --- Language --- English");
    add("420","Dewey Decimal Classification System --- Language --- English --- Old English");
    add("421","Dewey Decimal Classification System --- Language --- English --- English writing system & phonology");
    add("422","Dewey Decimal Classification System --- Language --- English --- English etymology");
    add("423","Dewey Decimal Classification System --- Language --- English --- English dictionaries");
    add("425","Dewey Decimal Classification System --- Language --- English --- English grammar");
    add("427","Dewey Decimal Classification System --- Language --- English --- English language variations");
    add("428","Dewey Decimal Classification System --- Language --- English --- Standard English usage");
    add("429","Dewey Decimal Classification System --- Language --- English --- Anglo-Saxon & Old English");
    add("430","Dewey Decimal Classification System --- Language --- Germanic languages");
    add("431","Dewey Decimal Classification System --- Language --- German writing system & phonology");
    add("432","Dewey Decimal Classification System --- Language --- German etymology");
    add("433","Dewey Decimal Classification System --- Language --- German dictionaries");
    add("435","Dewey Decimal Classification System --- Language --- German grammar");
    add("437","Dewey Decimal Classification System --- Language --- German language variations");
    add("438","Dewey Decimal Classification System --- Language --- German usage, Standard");
    add("439","Dewey Decimal Classification System --- Language --- Germanic languages, other");
    add("440","Dewey Decimal Classification System --- Language --- French & Romance languages");
    add("441","Dewey Decimal Classification System --- Language --- French writing system & phonology");
    add("442","Dewey Decimal Classification System --- Language --- French etymology");
    add("443","Dewey Decimal Classification System --- Language --- French dictionaries");
    add("445","Dewey Decimal Classification System --- Language --- French grammar");
    add("447","Dewey Decimal Classification System --- Language --- French language variations");
    add("448","Dewey Decimal Classification System --- Language --- French usage, Standard");
    add("449","Dewey Decimal Classification System --- Language --- Catalan and Provenal");
    add("450","Dewey Decimal Classification System --- Language --- Italian, Rhaeto-Romanic & Romanian languages");
    add("451","Dewey Decimal Classification System --- Language --- Italian writing system & phonology");
    add("452","Dewey Decimal Classification System --- Language --- Italian etymology");
    add("453","Dewey Decimal Classification System --- Language --- Italian dictionaries");
    add("455","Dewey Decimal Classification System --- Language --- Italian grammar");
    add("457","Dewey Decimal Classification System --- Language --- Italian language variations");
    add("458","Dewey Decimal Classification System --- Language --- Italian usage, Standard");
    add("459","Dewey Decimal Classification System --- Language --- Rhaeto-Romanic & Romanian languages");
    add("460","Dewey Decimal Classification System --- Language --- Portuguese & Spanish");
    add("461","Dewey Decimal Classification System --- Language --- Spanish writing system & phonology");
    add("462","Dewey Decimal Classification System --- Language --- Spanish etymology");
    add("463","Dewey Decimal Classification System --- Language --- Spanish dictionaries");
    add("465","Dewey Decimal Classification System --- Language --- Spanish grammar");
    add("467","Dewey Decimal Classification System --- Language --- Spanish language variations");
    add("468","Dewey Decimal Classification System --- Language --- Spanish usage, Standard");
    add("469","Dewey Decimal Classification System --- Language --- Portuguese");
    add("470","Dewey Decimal Classification System --- Language --- Italic languages & Latin");
    add("471","Dewey Decimal Classification System --- Language --- Latin writing system & phonology, Classical");
    add("472","Dewey Decimal Classification System --- Language --- Latin etymology, Classical");
    add("473","Dewey Decimal Classification System --- Language --- Latin dictionaries, Classical");
    add("475","Dewey Decimal Classification System --- Language --- Latin grammar, Classical");
    add("477","Dewey Decimal Classification System --- Language --- Old, Postclassical and Vulgar Latin");
    add("478","Dewey Decimal Classification System --- Language --- Latin usage, Classical");
    add("479","Dewey Decimal Classification System --- Language --- Italic languages, Other");
    add("480","Dewey Decimal Classification System --- Language --- Classical Greek & Hellenic languages");
    add("481","Dewey Decimal Classification System --- Language --- Greek writing system & phonology, Classical");
    add("482","Dewey Decimal Classification System --- Language --- Greek etymology, Classical");
    add("483","Dewey Decimal Classification System --- Language --- Greek dictionaries, Classical");
    add("485","Dewey Decimal Classification System --- Language --- Greek grammar, Classical");
    add("487","Dewey Decimal Classification System --- Language --- Greek language variations, Classical");
    add("488","Dewey Decimal Classification System --- Language --- Greek usage, Classical");
    add("489","Dewey Decimal Classification System --- Language --- Hellenic languages, Other");
    add("490","Dewey Decimal Classification System --- Language --- Languages, Other");
    add("491","Dewey Decimal Classification System --- Language --- Celtic languages & East Indo-European languages");
    add("492","Dewey Decimal Classification System --- Language --- Afro-Asiatic Semitic languages");
    add("493","Dewey Decimal Classification System --- Language --- Afro-Asiatic Non-Semitic languages");
    add("494","Dewey Decimal Classification System --- Language --- Dravidian, Paleosiberian &  Ural-Altaic languages");
    add("495","Dewey Decimal Classification System --- Language --- Languages of East & Southeast Asia");
    add("496","Dewey Decimal Classification System --- Language --- African languages");
    add("497","Dewey Decimal Classification System --- Language --- North American native languages");
    add("498","Dewey Decimal Classification System --- Language --- South American native languages");
    add("499","Dewey Decimal Classification System --- Language --- Languages, miscellaneous");
    add("500","Dewey Decimal Classification System --- Natural sciences");
    add("501","Dewey Decimal Classification System --- Natural sciences --- Natural sciences --- Philosophy & theory");
    add("502","Dewey Decimal Classification System --- Natural sciences --- Natural sciences --- Miscellany");
    add("503","Dewey Decimal Classification System --- Natural sciences --- Natural sciences --- Dictionaries & encyclopedias");
    add("505","Dewey Decimal Classification System --- Natural sciences --- Natural sciences --- Serial publications");
    add("506","Dewey Decimal Classification System --- Natural sciences --- Natural sciences --- Organizations & management");
    add("507","Dewey Decimal Classification System --- Natural sciences --- Natural sciences --- Education, research, related topics");
    add("508","Dewey Decimal Classification System --- Natural sciences --- Natural sciences --- Natural history");
    add("509","Dewey Decimal Classification System --- Natural sciences --- Natural sciences --- Historical, areas, persons treatment");
    add("510","Dewey Decimal Classification System --- Natural sciences --- Mathematics");
    add("511","Dewey Decimal Classification System --- Natural sciences --- Mathematics --- Mathematics, General topics");
    add("512","Dewey Decimal Classification System --- Natural sciences --- Mathematics --- Algebra & Number theory");
    add("513","Dewey Decimal Classification System --- Natural sciences --- Mathematics --- Arithmetic");
    add("514","Dewey Decimal Classification System --- Natural sciences --- Mathematics --- Topology");
    add("515","Dewey Decimal Classification System --- Natural sciences --- Mathematics --- Analysis");
    add("516","Dewey Decimal Classification System --- Natural sciences --- Mathematics --- Geometry");
    add("519","Dewey Decimal Classification System --- Natural sciences --- Mathematics --- Applied mathematics & Probabilities");
    add("520","Dewey Decimal Classification System --- Natural sciences --- Astronomy");
    add("521","Dewey Decimal Classification System --- Natural sciences --- Astronomy --- Celestial mechanics");
    add("522","Dewey Decimal Classification System --- Natural sciences --- Astronomy --- Astronomy, Techniques, equipment, materials");
    add("523","Dewey Decimal Classification System --- Natural sciences --- Astronomy --- Astronomy, Specific celestial bodies & phenomena");
    add("525","Dewey Decimal Classification System --- Natural sciences --- Astronomy --- Astronomy, Earth");
    add("526","Dewey Decimal Classification System --- Natural sciences --- Astronomy --- Mathematical geography");
    add("527","Dewey Decimal Classification System --- Natural sciences --- Astronomy --- Celestial navigation");
    add("528","Dewey Decimal Classification System --- Natural sciences --- Astronomy --- Ephemerides");
    add("529","Dewey Decimal Classification System --- Natural sciences --- Astronomy --- Chronology");
    add("530","Dewey Decimal Classification System --- Natural sciences --- Physics");
    add("531","Dewey Decimal Classification System --- Natural sciences --- Physics --- Classical and Solid Mechanics");
    add("532","Dewey Decimal Classification System --- Natural sciences --- Physics --- Fluid & Liquid Mechanics");
    add("533","Dewey Decimal Classification System --- Natural sciences --- Physics --- Gas Mechanics");
    add("534","Dewey Decimal Classification System --- Natural sciences --- Physics --- Sound & related vibrations");
    add("535","Dewey Decimal Classification System --- Natural sciences --- Physics --- Light & related radiations");
    add("536","Dewey Decimal Classification System --- Natural sciences --- Physics --- Heat");
    add("537","Dewey Decimal Classification System --- Natural sciences --- Physics --- Electriticy & Electronics");
    add("538","Dewey Decimal Classification System --- Natural sciences --- Physics --- Magnetism");
    add("539","Dewey Decimal Classification System --- Natural sciences --- Physics --- Modern Physics");
    add("540","Dewey Decimal Classification System --- Natural sciences --- Chemistry & allied sciences");
    add("541","Dewey Decimal Classification System --- Natural sciences --- Chemistry & allied sciences --- Physical & Theoretical Chemistry");
    add("542","Dewey Decimal Classification System --- Natural sciences --- Chemistry & allied sciences --- Chemistry, Techniques, equipment, materials");
    add("543","Dewey Decimal Classification System --- Natural sciences --- Chemistry & allied sciences --- Chemistry, Analytical");
    add("544","Dewey Decimal Classification System --- Natural sciences --- Chemistry & allied sciences --- Analysis, Qualitative");
    add("545","Dewey Decimal Classification System --- Natural sciences --- Chemistry & allied sciences --- Analysis, Quantitative");
    add("546","Dewey Decimal Classification System --- Natural sciences --- Chemistry & allied sciences --- Chemistry, Inorganic");
    add("547","Dewey Decimal Classification System --- Natural sciences --- Chemistry & allied sciences --- Chemistry, Organic");
    add("548","Dewey Decimal Classification System --- Natural sciences --- Chemistry & allied sciences --- Crystallography");
    add("549","Dewey Decimal Classification System --- Natural sciences --- Chemistry & allied sciences --- Mineralogy");
    add("550","Dewey Decimal Classification System --- Natural sciences --- Earth sciences");
    add("551","Dewey Decimal Classification System --- Natural sciences --- Earth sciences --- Geology, Hydrology & Meteorology");
    add("552","Dewey Decimal Classification System --- Natural sciences --- Earth sciences --- Petrology");
    add("553","Dewey Decimal Classification System --- Natural sciences --- Earth sciences --- Geology, Economic");
    add("554","Dewey Decimal Classification System --- Natural sciences --- Earth sciences --- Earth sciences of Europe");
    add("555","Dewey Decimal Classification System --- Natural sciences --- Earth sciences --- Earth sciences of Asia");
    add("556","Dewey Decimal Classification System --- Natural sciences --- Earth sciences --- Earth sciences of Africa");
    add("557","Dewey Decimal Classification System --- Natural sciences --- Earth sciences --- Earth sciences of North America");
    add("558","Dewey Decimal Classification System --- Natural sciences --- Earth sciences --- Earth sciences of South America");
    add("559","Dewey Decimal Classification System --- Natural sciences --- Earth sciences --- Earth sciences of other areas");
    add("560","Dewey Decimal Classification System --- Natural sciences --- Paleontology & Paleozoology");
    add("561","Dewey Decimal Classification System --- Natural sciences --- Paleontology & Paleozoology --- Paleobotany");
    add("562","Dewey Decimal Classification System --- Natural sciences --- Paleontology & Paleozoology --- Fossil invertebrates");
    add("563","Dewey Decimal Classification System --- Natural sciences --- Paleontology & Paleozoology --- Fossil primitive phyla");
    add("564","Dewey Decimal Classification System --- Natural sciences --- Paleontology & Paleozoology --- Fossil mollusks & related phyla");
    add("565","Dewey Decimal Classification System --- Natural sciences --- Paleontology & Paleozoology --- Fossil invertebrates, Other");
    add("566","Dewey Decimal Classification System --- Natural sciences --- Paleontology & Paleozoology --- Fossil vertebrates");
    add("567","Dewey Decimal Classification System --- Natural sciences --- Paleontology & Paleozoology --- Fossil cold-blooded vertebrates");
    add("568","Dewey Decimal Classification System --- Natural sciences --- Paleontology & Paleozoology --- Fossil birds");
    add("569","Dewey Decimal Classification System --- Natural sciences --- Paleontology & Paleozoology --- Fossil mammals");
    add("570","Dewey Decimal Classification System --- Natural sciences --- Life sciences");
    add("572","Dewey Decimal Classification System --- Natural sciences --- Life sciences --- Human races");
    add("573","Dewey Decimal Classification System --- Natural sciences --- Life sciences --- Physical anthropology");
    add("574","Dewey Decimal Classification System --- Natural sciences --- Life sciences --- Biology");
    add("575","Dewey Decimal Classification System --- Natural sciences --- Life sciences --- Evolution & Genetics");
    add("576","Dewey Decimal Classification System --- Natural sciences --- Life sciences --- Microbiology");
    add("577","Dewey Decimal Classification System --- Natural sciences --- Life sciences --- General nature of Life");
    add("578","Dewey Decimal Classification System --- Natural sciences --- Life sciences --- Microscopy in biology");
    add("579","Dewey Decimal Classification System --- Natural sciences --- Life sciences --- Biology, Collection and preservation");
    add("580","Dewey Decimal Classification System --- Natural sciences --- Botanical sciences");
    add("581","Dewey Decimal Classification System --- Natural sciences --- Botanical sciences --- Botany");
    add("582","Dewey Decimal Classification System --- Natural sciences --- Botanical sciences --- Plants, Seed-bearing");
    add("583","Dewey Decimal Classification System --- Natural sciences --- Botanical sciences --- Dicotyledons");
    add("584","Dewey Decimal Classification System --- Natural sciences --- Botanical sciences --- Monocotyledons");
    add("585","Dewey Decimal Classification System --- Natural sciences --- Botanical sciences --- Gymnosperms & Naked-seed plants");
    add("586","Dewey Decimal Classification System --- Natural sciences --- Botanical sciences --- Plants, Seedless");
    add("587","Dewey Decimal Classification System --- Natural sciences --- Botanical sciences --- Pteridophyta & Vascular seedless plants");
    add("588","Dewey Decimal Classification System --- Natural sciences --- Botanical sciences --- Bryophytes");
    add("589","Dewey Decimal Classification System --- Natural sciences --- Botanical sciences --- Prokaryotes & Thallophytes");
    add("590","Dewey Decimal Classification System --- Natural sciences --- Zoological sciences");
    add("591","Dewey Decimal Classification System --- Natural sciences --- Zoological sciences --- Zoology");
    add("592","Dewey Decimal Classification System --- Natural sciences --- Zoological sciences --- Invertebrates");
    add("593","Dewey Decimal Classification System --- Natural sciences --- Zoological sciences --- Echinodermata & Protozoa");
    add("594","Dewey Decimal Classification System --- Natural sciences --- Zoological sciences --- Mollusks & related phyla");
    add("595","Dewey Decimal Classification System --- Natural sciences --- Zoological sciences --- Invertebrates, Other");
    add("596","Dewey Decimal Classification System --- Natural sciences --- Zoological sciences --- Vertebrates");
    add("597","Dewey Decimal Classification System --- Natural sciences --- Zoological sciences --- Vertebrates, Cold-blooded");
    add("598","Dewey Decimal Classification System --- Natural sciences --- Zoological sciences --- Birds");
    add("599","Dewey Decimal Classification System --- Natural sciences --- Zoological sciences --- Mammals");
    add("600","Dewey Decimal Classification System --- Applied sciences");
    add("600","Dewey Decimal Classification System --- Applied sciences --- Technology");
    add("601","Dewey Decimal Classification System --- Applied sciences --- Technology --- Technology, Philosophy & theory");
    add("602","Dewey Decimal Classification System --- Applied sciences --- Technology --- Technology, Miscellany");
    add("603","Dewey Decimal Classification System --- Applied sciences --- Technology --- Technology, Dictionaries & encyclopedias");
    add("604","Dewey Decimal Classification System --- Applied sciences --- Technology --- Technology, Special topics");
    add("605","Dewey Decimal Classification System --- Applied sciences --- Technology --- Technology, Serial publications");
    add("606","Dewey Decimal Classification System --- Applied sciences --- Technology --- Technology, Organizations");
    add("607","Dewey Decimal Classification System --- Applied sciences --- Technology --- Technology, Education, research, related topics");
    add("608","Dewey Decimal Classification System --- Applied sciences --- Technology --- Invention & patents");
    add("609","Dewey Decimal Classification System --- Applied sciences --- Technology --- Technology, Historical, areas, persons treatment");
    add("610","Dewey Decimal Classification System --- Applied sciences --- Medical sciences; Medicine");
    add("611","Dewey Decimal Classification System --- Applied sciences --- Medical sciences; Medicine --- Human Anatomy, Cytology & Histology");
    add("612","Dewey Decimal Classification System --- Applied sciences --- Medical sciences; Medicine --- Physiology, Human");
    add("613","Dewey Decimal Classification System --- Applied sciences --- Medical sciences; Medicine --- Promotion of Health");
    add("614","Dewey Decimal Classification System --- Applied sciences --- Medical sciences; Medicine --- Incidence & prevention of Disease");
    add("615","Dewey Decimal Classification System --- Applied sciences --- Medical sciences; Medicine --- Pharmacology & Therapeutics");
    add("616","Dewey Decimal Classification System --- Applied sciences --- Medical sciences; Medicine --- Diseases");
    add("617","Dewey Decimal Classification System --- Applied sciences --- Medical sciences; Medicine --- Surgery & related medical specialties");
    add("618","Dewey Decimal Classification System --- Applied sciences --- Medical sciences; Medicine --- Gynecology & other medical specialties");
    add("619","Dewey Decimal Classification System --- Applied sciences --- Medical sciences; Medicine --- Medicine, Experimental");
    add("620","Dewey Decimal Classification System --- Applied sciences --- Engineering & allied operations");
    add("621","Dewey Decimal Classification System --- Applied sciences --- Engineering & allied operations --- Applied physics");
    add("622","Dewey Decimal Classification System --- Applied sciences --- Engineering & allied operations --- Mining & related operations");
    add("623","Dewey Decimal Classification System --- Applied sciences --- Engineering & allied operations --- Military & Nautical engineering"); 
    add("624","Dewey Decimal Classification System --- Applied sciences --- Engineering & allied operations --- Civil engineering"); 
    add("625","Dewey Decimal Classification System --- Applied sciences --- Engineering & allied operations --- Engineering of railroads, roads");
    add("627","Dewey Decimal Classification System --- Applied sciences --- Engineering & allied operations --- Hydraulic engineering");
    add("628","Dewey Decimal Classification System --- Applied sciences --- Engineering & allied operations --- Municipal, Sanitary & Environmental protection engineering");
    add("629","Dewey Decimal Classification System --- Applied sciences --- Engineering & allied operations --- Engineering, Other branches of");
    add("630","Dewey Decimal Classification System --- Applied sciences --- Agriculture");
    add("631","Dewey Decimal Classification System --- Applied sciences --- Agriculture --- Agricultural Techniques, equipment, materials");
    add("632","Dewey Decimal Classification System --- Applied sciences --- Agriculture --- Plant injuries, diseases, pests");
    add("633","Dewey Decimal Classification System --- Applied sciences --- Agriculture --- Crops, Field & plantation");
    add("634","Dewey Decimal Classification System --- Applied sciences --- Agriculture --- Forestry, Fruits & Orchards");
    add("635","Dewey Decimal Classification System --- Applied sciences --- Agriculture --- Garden crops & Horticulture");
    add("636","Dewey Decimal Classification System --- Applied sciences --- Agriculture --- Animal husbandry");
    add("637","Dewey Decimal Classification System --- Applied sciences --- Agriculture --- Dairy products, Processing");
    add("638","Dewey Decimal Classification System --- Applied sciences --- Agriculture --- Insect culture");
    add("639","Dewey Decimal Classification System --- Applied sciences --- Agriculture --- Conservation, Fishing & Hunting");
    add("640","Dewey Decimal Classification System --- Applied sciences --- Family living & Home economics");
    add("641","Dewey Decimal Classification System --- Applied sciences --- Family living & Home economics --- Drink & Food");
    add("642","Dewey Decimal Classification System --- Applied sciences --- Family living & Home economics --- Meals & Table service");
    add("643","Dewey Decimal Classification System --- Applied sciences --- Family living & Home economics --- Household equipment & Housing");
    add("644","Dewey Decimal Classification System --- Applied sciences --- Family living & Home economics --- Household utilities");
    add("645","Dewey Decimal Classification System --- Applied sciences --- Family living & Home economics --- Household furnishings");
    add("646","Dewey Decimal Classification System --- Applied sciences --- Family living & Home economics --- Clothing & Personal living & Sewing");
    add("647","Dewey Decimal Classification System --- Applied sciences --- Family living & Home economics --- Public households, Management of");
    add("648","Dewey Decimal Classification System --- Applied sciences --- Family living & Home economics --- Housekeeping");
    add("649","Dewey Decimal Classification System --- Applied sciences --- Family living & Home economics --- Child rearing & Home care of sick");
    add("650","Dewey Decimal Classification System --- Applied sciences --- Management & auxiliary services");
    add("651","Dewey Decimal Classification System --- Applied sciences --- Management & auxiliary services --- Office services");
    add("652","Dewey Decimal Classification System --- Applied sciences --- Management & auxiliary services --- Written communication, Processes of");
    add("653","Dewey Decimal Classification System --- Applied sciences --- Management & auxiliary services --- Shorthand");
    add("657","Dewey Decimal Classification System --- Applied sciences --- Management & auxiliary services --- Accounting");
    add("658","Dewey Decimal Classification System --- Applied sciences --- Management & auxiliary services --- Management, General");
    add("659","Dewey Decimal Classification System --- Applied sciences --- Management & auxiliary services --- Advertising & Public relations");
    add("660","Dewey Decimal Classification System --- Applied sciences --- Chemical engineering");
    add("661","Dewey Decimal Classification System --- Applied sciences --- Chemical engineering --- Chemicals technology, Industrial");
    add("662","Dewey Decimal Classification System --- Applied sciences --- Chemical engineering --- Explosives & Fuels technology");
    add("663","Dewey Decimal Classification System --- Applied sciences --- Chemical engineering --- Beverage technology");
    add("664","Dewey Decimal Classification System --- Applied sciences --- Chemical engineering --- Food technology");
    add("665","Dewey Decimal Classification System --- Applied sciences --- Chemical engineering --- Industrial Fats, Gases, Oils & Waxes");
    add("666","Dewey Decimal Classification System --- Applied sciences --- Chemical engineering --- Ceramic technologies");
    add("667","Dewey Decimal Classification System --- Applied sciences --- Chemical engineering --- Cleaning & Color");
    add("668","Dewey Decimal Classification System --- Applied sciences --- Chemical engineering --- Organic products, Technology of other");
    add("669","Dewey Decimal Classification System --- Applied sciences --- Chemical engineering --- Metallurgy");
    add("670","Dewey Decimal Classification System --- Applied sciences --- Manufacturing");
    add("671","Dewey Decimal Classification System --- Applied sciences --- Manufacturing --- Metal products & Metalworking");
    add("672","Dewey Decimal Classification System --- Applied sciences --- Manufacturing --- Iron, Steel, Iron alloys & other");
    add("673","Dewey Decimal Classification System --- Applied sciences --- Manufacturing --- Nonferrous Metals");
    add("674","Dewey Decimal Classification System --- Applied sciences --- Manufacturing --- Cork & Lumber processing & Wood products");
    add("675","Dewey Decimal Classification System --- Applied sciences --- Manufacturing --- Fur processing & Leather processing");
    add("676","Dewey Decimal Classification System --- Applied sciences --- Manufacturing --- Paper & Pulp technology");
    add("677","Dewey Decimal Classification System --- Applied sciences --- Manufacturing --- Textiles");
    add("678","Dewey Decimal Classification System --- Applied sciences --- Manufacturing --- Elastomers & elastomer products");
    add("679","Dewey Decimal Classification System --- Applied sciences --- Manufacturing --- Products of specific materials, Other");
    add("680","Dewey Decimal Classification System --- Applied sciences --- Manufacture for specific uses");
    add("681","Dewey Decimal Classification System --- Applied sciences --- Manufacture for specific uses --- Precision instruments & other devices");
    add("682","Dewey Decimal Classification System --- Applied sciences --- Manufacture for specific uses --- Blacksmithing & Small forge work");
    add("683","Dewey Decimal Classification System --- Applied sciences --- Manufacture for specific uses --- Hardware & Household appliences");
    add("684","Dewey Decimal Classification System --- Applied sciences --- Manufacture for specific uses --- Furnishings & Home workshops");
    add("685","Dewey Decimal Classification System --- Applied sciences --- Manufacture for specific uses --- Fur & Leather");
    add("686","Dewey Decimal Classification System --- Applied sciences --- Manufacture for specific uses --- Printing & related activities");
    add("687","Dewey Decimal Classification System --- Applied sciences --- Manufacture for specific uses --- Clothing");
    add("688","Dewey Decimal Classification System --- Applied sciences --- Manufacture for specific uses --- Final products & packaging, Other");
    add("690","Dewey Decimal Classification System --- Applied sciences --- Buildings");
    add("691","Dewey Decimal Classification System --- Applied sciences --- Buildings --- Building materials");
    add("692","Dewey Decimal Classification System --- Applied sciences --- Buildings --- Construction practices, Auxiliary");
    add("693","Dewey Decimal Classification System --- Applied sciences --- Buildings --- Construction materials & purposes, Specific");
    add("694","Dewey Decimal Classification System --- Applied sciences --- Buildings --- Carpentry & Wood Construction");
    add("695","Dewey Decimal Classification System --- Applied sciences --- Buildings --- Roof covering");
    add("696","Dewey Decimal Classification System --- Applied sciences --- Buildings --- Utilities");
    add("697","Dewey Decimal Classification System --- Applied sciences --- Buildings --- Air-conditioning, Heating & Ventilation");
    add("698","Dewey Decimal Classification System --- Applied sciences --- Buildings --- Detail finishing");
    add("700","Dewey Decimal Classification System --- Arts & Entertainment --- Arts");
    add("701","Dewey Decimal Classification System --- Arts & Entertainment --- Arts --- Arts, Philosophy & theory");
    add("702","Dewey Decimal Classification System --- Arts & Entertainment --- Arts --- Arts, Miscellany");
    add("703","Dewey Decimal Classification System --- Arts & Entertainment --- Arts --- Arts, Dictionaries & encyclopedias");
    add("704","Dewey Decimal Classification System --- Arts & Entertainment --- Arts --- Arts, Special topics");
    add("705","Dewey Decimal Classification System --- Arts & Entertainment --- Arts --- Arts, Serial publications");
    add("706","Dewey Decimal Classification System --- Arts & Entertainment --- Arts --- Arts, Organizations & management");
    add("707","Dewey Decimal Classification System --- Arts & Entertainment --- Arts --- Arts, Education, research, related topics");
    add("708","Dewey Decimal Classification System --- Arts & Entertainment --- Arts --- Arts, Galleries, museums, private collections");
    add("709","Dewey Decimal Classification System --- Arts & Entertainment --- Arts --- Arts, Historical, areas, persons treatment");
    add("710","Dewey Decimal Classification System --- Arts & Entertainment --- Civic & Landscape Art");
    add("711","Dewey Decimal Classification System --- Arts & Entertainment --- Civic & Landscape Art --- Area planning & Civic Art");
    add("712","Dewey Decimal Classification System --- Arts & Entertainment --- Civic & Landscape Art --- Landscape architecture");
    add("713","Dewey Decimal Classification System --- Arts & Entertainment --- Civic & Landscape Art --- Landscape architecture of trafficways");
    add("714","Dewey Decimal Classification System --- Arts & Entertainment --- Civic & Landscape Art --- Landscape architecture, Water features");
    add("715","Dewey Decimal Classification System --- Arts & Entertainment --- Civic & Landscape Art --- Landscape architecture, Woody plants");
    add("716","Dewey Decimal Classification System --- Arts & Entertainment --- Civic & Landscape Art --- Landscape architecture, Herbaceous plants");
    add("717","Dewey Decimal Classification System --- Arts & Entertainment --- Civic & Landscape Art --- Landscape architecture, Structures");
    add("718","Dewey Decimal Classification System --- Arts & Entertainment --- Civic & Landscape Art --- Landscape design of cemeteries");
    add("719","Dewey Decimal Classification System --- Arts & Entertainment --- Civic & Landscape Art --- Landscapes, Natural");
    add("720","Dewey Decimal Classification System --- Arts & Entertainment --- Architecture");
    add("721","Dewey Decimal Classification System --- Arts & Entertainment --- Architecture --- Architectural structure");
    add("722","Dewey Decimal Classification System --- Arts & Entertainment --- Architecture --- Architecture to ca. 300");
    add("723","Dewey Decimal Classification System --- Arts & Entertainment --- Architecture --- Architecture from ca. 300 to 1399");
    add("724","Dewey Decimal Classification System --- Arts & Entertainment --- Architecture --- Architecture from 1400");
    add("725","Dewey Decimal Classification System --- Arts & Entertainment --- Architecture --- Public structures");
    add("726","Dewey Decimal Classification System --- Arts & Entertainment --- Architecture --- Buildings for religious purposes");
    add("727","Dewey Decimal Classification System --- Arts & Entertainment --- Architecture --- Buildings for education & research");
    add("728","Dewey Decimal Classification System --- Arts & Entertainment --- Architecture --- Buildings, Residential");
    add("729","Dewey Decimal Classification System --- Arts & Entertainment --- Architecture --- Decoration & Design");
    add("730","Dewey Decimal Classification System --- Arts & Entertainment --- Plastic arts & Sculpture");
    add("731","Dewey Decimal Classification System --- Arts & Entertainment --- Plastic arts & Sculpture --- Sculpture, Processes, forms, subjects of");
    add("732","Dewey Decimal Classification System --- Arts & Entertainment --- Plastic arts & Sculpture --- Sculpture to ca. 500");
    add("733","Dewey Decimal Classification System --- Arts & Entertainment --- Plastic arts & Sculpture --- Etruscan, Greek & Roman Sculpture");
    add("734","Dewey Decimal Classification System --- Arts & Entertainment --- Plastic arts & Sculpture --- Sculpture from ca. 500 to 1399");
    add("735","Dewey Decimal Classification System --- Arts & Entertainment --- Plastic arts & Sculpture --- Sculpture from 1400");
    add("736","Dewey Decimal Classification System --- Arts & Entertainment --- Plastic arts & Sculpture --- Carving & carvings");
    add("737","Dewey Decimal Classification System --- Arts & Entertainment --- Plastic arts & Sculpture --- Numismatics & Sigillography");
    add("738","Dewey Decimal Classification System --- Arts & Entertainment --- Plastic arts & Sculpture --- Ceramic arts");
    add("739","Dewey Decimal Classification System --- Arts & Entertainment --- Plastic arts & Sculpture --- Metalwork, Art");
    add("740","Dewey Decimal Classification System --- Arts & Entertainment --- Decorative arts & Drawing");
    add("741","Dewey Decimal Classification System --- Arts & Entertainment --- Decorative arts & Drawing --- Drawing & drawings");
    add("742","Dewey Decimal Classification System --- Arts & Entertainment --- Decorative arts & Drawing --- Perspective");
    add("743","Dewey Decimal Classification System --- Arts & Entertainment --- Decorative arts & Drawing --- Drawing & drawings by subject");
    add("745","Dewey Decimal Classification System --- Arts & Entertainment --- Decorative arts & Drawing --- Decorative arts");
    add("746","Dewey Decimal Classification System --- Arts & Entertainment --- Decorative arts & Drawing --- Textile arts");
    add("747","Dewey Decimal Classification System --- Arts & Entertainment --- Decorative arts & Drawing --- Interior decoration");
    add("748","Dewey Decimal Classification System --- Arts & Entertainment --- Decorative arts & Drawing --- Glass");
    add("749","Dewey Decimal Classification System --- Arts & Entertainment --- Decorative arts & Drawing --- Accessories & Furniture");
    add("750","Dewey Decimal Classification System --- Arts & Entertainment --- Painting & paintings");
    add("751","Dewey Decimal Classification System --- Arts & Entertainment --- Painting & paintings --- Painting, Techniques, equipment, forms");
    add("752","Dewey Decimal Classification System --- Arts & Entertainment --- Painting & paintings --- Color");
    add("753","Dewey Decimal Classification System --- Arts & Entertainment --- Painting & paintings --- Allegory, Legend, Mythology & Symbolism in painting");
    add("754","Dewey Decimal Classification System --- Arts & Entertainment --- Painting & paintings --- Genre paintings");
    add("755","Dewey Decimal Classification System --- Arts & Entertainment --- Painting & paintings --- Paintings, Religion & religious symbolism");
    add("757","Dewey Decimal Classification System --- Arts & Entertainment --- Painting & paintings --- Painting, Human figures & their parts");
    add("758","Dewey Decimal Classification System --- Arts & Entertainment --- Painting & paintings --- Painting, Other subjects");
    add("759","Dewey Decimal Classification System --- Arts & Entertainment --- Painting & paintings --- Painting, Historical, areas, persons treatment");
    add("760","Dewey Decimal Classification System --- Arts & Entertainment --- Graphic arts, Printmaking & prints");
    add("761","Dewey Decimal Classification System --- Arts & Entertainment --- Graphic arts, Printmaking & prints --- Block printing &Relief processes");
    add("763","Dewey Decimal Classification System --- Arts & Entertainment --- Graphic arts, Printmaking & prints --- Lithographic processes & Planographic processes");
    add("764","Dewey Decimal Classification System --- Arts & Entertainment --- Graphic arts, Printmaking & prints --- Chromolithography & Serigraphy");
    add("765","Dewey Decimal Classification System --- Arts & Entertainment --- Graphic arts, Printmaking & prints --- Metal engraving");
    add("766","Dewey Decimal Classification System --- Arts & Entertainment --- Graphic arts, Printmaking & prints --- Mezzotinting & related processes");
    add("767","Dewey Decimal Classification System --- Arts & Entertainment --- Graphic arts, Printmaking & prints --- Drypoint & Etching");
    add("769","Dewey Decimal Classification System --- Arts & Entertainment --- Graphic arts, Printmaking & prints --- Prints");
    add("770","Dewey Decimal Classification System --- Arts & Entertainment --- Photography & photographs");
    add("771","Dewey Decimal Classification System --- Arts & Entertainment --- Photography & photographs --- Photographic Techniques, equipment, materials");
    add("772","Dewey Decimal Classification System --- Arts & Entertainment --- Photography & photographs --- Photography, Metallic salt processes");
    add("773","Dewey Decimal Classification System --- Arts & Entertainment --- Photography & photographs --- Photography, Pigment processes of printing");
    add("774","Dewey Decimal Classification System --- Arts & Entertainment --- Photography & photographs --- Holography");
    add("778","Dewey Decimal Classification System --- Arts & Entertainment --- Photography & photographs --- Photography, Fields & kinds of");
    add("779","Dewey Decimal Classification System --- Arts & Entertainment --- Photography & photographs --- Photographs");
    add("780","Dewey Decimal Classification System --- Arts & Entertainment --- Music");
    add("781","Dewey Decimal Classification System --- Arts & Entertainment --- Music --- Music, General principles & musical forms");
    add("782","Dewey Decimal Classification System --- Arts & Entertainment --- Music --- Music, Vocal");
    add("783","Dewey Decimal Classification System --- Arts & Entertainment --- Music --- Music for single voices; The voice");
    add("784","Dewey Decimal Classification System --- Arts & Entertainment --- Music --- Music, Instruments & instrumental ensembles");
    add("785","Dewey Decimal Classification System --- Arts & Entertainment --- Music --- Music, Chamber");
    add("786","Dewey Decimal Classification System --- Arts & Entertainment --- Music --- Music, Keyboard & other instruments");
    add("787","Dewey Decimal Classification System --- Arts & Entertainment --- Music --- Music, Stringed instruments");
    add("788","Dewey Decimal Classification System --- Arts & Entertainment --- Music --- Music, Wind instruments");
    add("790","Dewey Decimal Classification System --- Arts & Entertainment --- Performing & Recreational arts");
    add("791","Dewey Decimal Classification System --- Arts & Entertainment --- Performing & Recreational arts --- Public performances");
    add("792","Dewey Decimal Classification System --- Arts & Entertainment --- Performing & Recreational arts --- Stage presentations");
    add("793","Dewey Decimal Classification System --- Arts & Entertainment --- Performing & Recreational arts --- Games & amusements, Indoor");
    add("794","Dewey Decimal Classification System --- Arts & Entertainment --- Performing & Recreational arts --- Games of skill, Indoor");
    add("795","Dewey Decimal Classification System --- Arts & Entertainment --- Performing & Recreational arts --- Games of chance");
    add("796","Dewey Decimal Classification System --- Arts & Entertainment --- Performing & Recreational arts --- Sports & games, Athletic & outdoor");
    add("797","Dewey Decimal Classification System --- Arts & Entertainment --- Performing & Recreational arts --- Sports, Aquatic & air");
    add("798","Dewey Decimal Classification System --- Arts & Entertainment --- Performing & Recreational arts --- Sports & animal racing, Equestrian");
    add("799","Dewey Decimal Classification System --- Arts & Entertainment --- Performing & Recreational arts --- Fishing, hunting, & Shooting");
    add("800","Dewey Decimal Classification System --- Literature");
    add("801","Dewey Decimal Classification System --- Literature --- Literature --- Literature, Philosophy & theory");
    add("802","Dewey Decimal Classification System --- Literature --- Literature --- Literature, Miscellany");
    add("803","Dewey Decimal Classification System --- Literature --- Literature --- Literature, Dictionaries & encyclopedias");
    add("805","Dewey Decimal Classification System --- Literature --- Literature --- Literature, Serial publications");
    add("806","Dewey Decimal Classification System --- Literature --- Literature --- Literature, Organizations");
    add("807","Dewey Decimal Classification System --- Literature --- Literature --- Literature, Education, research, related topics");
    add("808","Dewey Decimal Classification System --- Literature --- Literature --- Rhetoric & collections of literature");
    add("809","Dewey Decimal Classification System --- Literature --- Literature --- Literary history & criticism");
    add("810","Dewey Decimal Classification System --- Literature --- American literature in English");
    add("811","Dewey Decimal Classification System --- Literature --- American literature in English --- American Poetry");
    add("812","Dewey Decimal Classification System --- Literature --- American literature in English --- American Drama");
    add("813","Dewey Decimal Classification System --- Literature --- American literature in English --- American Fiction");
    add("814","Dewey Decimal Classification System --- Literature --- American literature in English --- American Essays");
    add("815","Dewey Decimal Classification System --- Literature --- American literature in English --- American Speeches");
    add("816","Dewey Decimal Classification System --- Literature --- American literature in English --- American Letters");
    add("817","Dewey Decimal Classification System --- Literature --- American literature in English --- American Satire & humor");
    add("818","Dewey Decimal Classification System --- Literature --- American literature in English --- American Miscellaneous writings");
    add("820","Dewey Decimal Classification System --- Literature --- English & Old English literatures");
    add("821","Dewey Decimal Classification System --- Literature --- English & Old English literatures --- English poetry");
    add("822","Dewey Decimal Classification System --- Literature --- English & Old English literatures --- English drama");
    add("823","Dewey Decimal Classification System --- Literature --- English & Old English literatures --- English fiction");
    add("824","Dewey Decimal Classification System --- Literature --- English & Old English literatures --- English essays");
    add("825","Dewey Decimal Classification System --- Literature --- English & Old English literatures --- English speeches");
    add("826","Dewey Decimal Classification System --- Literature --- English & Old English literatures --- English letters");
    add("827","Dewey Decimal Classification System --- Literature --- English & Old English literatures --- English satire & humor");
    add("828","Dewey Decimal Classification System --- Literature --- English & Old English literatures --- English miscellaneous writings");
    add("829","Dewey Decimal Classification System --- Literature --- English & Old English literatures --- Old English (Anglo-Saxon)");
    add("830","Dewey Decimal Classification System --- Literature --- Literatures of Germanic languages");
    add("831","Dewey Decimal Classification System --- Literature --- Literatures of Germanic languages --- German poetry");
    add("832","Dewey Decimal Classification System --- Literature --- Literatures of Germanic languages --- German drama");
    add("833","Dewey Decimal Classification System --- Literature --- Literatures of Germanic languages --- German fiction");
    add("834","Dewey Decimal Classification System --- Literature --- Literatures of Germanic languages --- German essays");
    add("835","Dewey Decimal Classification System --- Literature --- Literatures of Germanic languages --- German speeches");
    add("836","Dewey Decimal Classification System --- Literature --- Literatures of Germanic languages --- German letters");
    add("837","Dewey Decimal Classification System --- Literature --- Literatures of Germanic languages --- German satire & humor");
    add("838","Dewey Decimal Classification System --- Literature --- Literatures of Germanic languages --- German miscellaneous writings");
    add("839","Dewey Decimal Classification System --- Literature --- Literatures of Germanic languages --- Germanic literatures, Other");
    add("840","Dewey Decimal Classification System --- Literature --- Literatures of Romance languages");
    add("841","Dewey Decimal Classification System --- Literature --- Literatures of Romance languages --- French poetry");
    add("842","Dewey Decimal Classification System --- Literature --- Literatures of Romance languages --- French drama");
    add("843","Dewey Decimal Classification System --- Literature --- Literatures of Romance languages --- French fiction");
    add("844","Dewey Decimal Classification System --- Literature --- Literatures of Romance languages --- French essays");
    add("845","Dewey Decimal Classification System --- Literature --- Literatures of Romance languages --- French speeches");
    add("846","Dewey Decimal Classification System --- Literature --- Literatures of Romance languages --- French letters");
    add("847","Dewey Decimal Classification System --- Literature --- Literatures of Romance languages --- French satire & humor");
    add("848","Dewey Decimal Classification System --- Literature --- Literatures of Romance languages --- French miscellaneous writings");
    add("849","Dewey Decimal Classification System --- Literature --- Literatures of Romance languages --- Provenal & Catalan");
    add("850","Dewey Decimal Classification System --- Literature --- Italian, Romanian, Rhaeto-Romanic");
    add("851","Dewey Decimal Classification System --- Literature --- Italian, Romanian, Rhaeto-Romanic --- Italian poetry");
    add("852","Dewey Decimal Classification System --- Literature --- Italian, Romanian, Rhaeto-Romanic --- Italian drama");
    add("853","Dewey Decimal Classification System --- Literature --- Italian, Romanian, Rhaeto-Romanic --- Italian fiction");
    add("854","Dewey Decimal Classification System --- Literature --- Italian, Romanian, Rhaeto-Romanic --- Italian essays");
    add("855","Dewey Decimal Classification System --- Literature --- Italian, Romanian, Rhaeto-Romanic --- Italian speeches");
    add("856","Dewey Decimal Classification System --- Literature --- Italian, Romanian, Rhaeto-Romanic --- Italian letters");
    add("857","Dewey Decimal Classification System --- Literature --- Italian, Romanian, Rhaeto-Romanic --- Italian satire & humor");
    add("858","Dewey Decimal Classification System --- Literature --- Italian, Romanian, Rhaeto-Romanic --- Italian miscellaneous writings");
    add("859","Dewey Decimal Classification System --- Literature --- Italian, Romanian, Rhaeto-Romanic --- Rhaeto-Romanic & Romanian");
    add("860","Dewey Decimal Classification System --- Literature --- Spanish & Portuguese literatures");
    add("861","Dewey Decimal Classification System --- Literature --- Spanish & Portuguese literatures --- Spanish poetry");
    add("862","Dewey Decimal Classification System --- Literature --- Spanish & Portuguese literatures --- Spanish drama");
    add("863","Dewey Decimal Classification System --- Literature --- Spanish & Portuguese literatures --- Spanish fiction");
    add("864","Dewey Decimal Classification System --- Literature --- Spanish & Portuguese literatures --- Spanish essays");
    add("865","Dewey Decimal Classification System --- Literature --- Spanish & Portuguese literatures --- Spanish speeches");
    add("866","Dewey Decimal Classification System --- Literature --- Spanish & Portuguese literatures --- Spanish letters");
    add("867","Dewey Decimal Classification System --- Literature --- Spanish & Portuguese literatures --- Spanish satire & humor");
    add("868","Dewey Decimal Classification System --- Literature --- Spanish & Portuguese literatures --- Spanish miscellaneous writings");
    add("869","Dewey Decimal Classification System --- Literature --- Spanish & Portuguese literatures --- Portuguese");
    add("870","Dewey Decimal Classification System --- Literature --- Latin & Old Latin literatures");
    add("871","Dewey Decimal Classification System --- Literature --- Latin & Old Latin literatures --- Latin poetry");
    add("872","Dewey Decimal Classification System --- Literature --- Latin & Old Latin literatures --- Latin drama");
    add("873","Dewey Decimal Classification System --- Literature --- Latin & Old Latin literatures --- Latin fiction");
    add("874","Dewey Decimal Classification System --- Literature --- Latin & Old Latin literatures --- Latin essays");
    add("875","Dewey Decimal Classification System --- Literature --- Latin & Old Latin literatures --- Latin speeches");
    add("876","Dewey Decimal Classification System --- Literature --- Latin & Old Latin literatures --- Latin letters");
    add("877","Dewey Decimal Classification System --- Literature --- Latin & Old Latin literatures --- Latin satire & humor");
    add("878","Dewey Decimal Classification System --- Literature --- Latin & Old Latin literatures --- Latin miscellaneous writings");
    add("879","Dewey Decimal Classification System --- Literature --- Latin & Old Latin literatures --- Literatures of other Italic languages");
    add("880","Dewey Decimal Classification System --- Literature --- Classical Greek & Hellenic literature");
    add("881","Dewey Decimal Classification System --- Literature --- Classical Greek & Hellenic literature --- Classical Greek poetry");
    add("882","Dewey Decimal Classification System --- Literature --- Classical Greek & Hellenic literature --- Classical Greek drama");
    add("883","Dewey Decimal Classification System --- Literature --- Classical Greek & Hellenic literature --- Classical Greek fiction");
    add("884","Dewey Decimal Classification System --- Literature --- Classical Greek & Hellenic literature --- Classical Greek essays");
    add("885","Dewey Decimal Classification System --- Literature --- Classical Greek & Hellenic literature --- Classical Greek speeches");
    add("886","Dewey Decimal Classification System --- Literature --- Classical Greek & Hellenic literature --- Classical Greek letters");
    add("887","Dewey Decimal Classification System --- Literature --- Classical Greek & Hellenic literature --- Classical Greek satire & humor");
    add("888","Dewey Decimal Classification System --- Literature --- Classical Greek & Hellenic literature --- Classical Greek miscellaneous writings");
    add("889","Dewey Decimal Classification System --- Literature --- Classical Greek & Hellenic literature --- Modern Greek literature");
    add("890","Dewey Decimal Classification System --- Literature --- Literatures of other languages");
    add("891","Dewey Decimal Classification System --- Literature --- Literatures of other languages --- Celtic &  East Indo-European literatures");
    add("892","Dewey Decimal Classification System --- Literature --- Literatures of other languages --- Afro-Asiatic & Semitic literatures");
    add("893","Dewey Decimal Classification System --- Literature --- Literatures of other languages --- Non-Semitic Afro-Asiatic literatures");
    add("894","Dewey Decimal Classification System --- Literature --- Literatures of other languages --- Dravidian, Paleosiberian & Ural-Altaic Literature");
    add("895","Dewey Decimal Classification System --- Literature --- Literatures of other languages --- Literatures of East & Southeast Asia");
    add("896","Dewey Decimal Classification System --- Literature --- Literatures of other languages --- African literatures");
    add("897","Dewey Decimal Classification System --- Literature --- Literatures of other languages --- North American native literatures");
    add("898","Dewey Decimal Classification System --- Literature --- Literatures of other languages --- South American native literatures");
    add("899","Dewey Decimal Classification System --- Literature --- Literatures of other languages --- Literatures, Other");
    add("900","Dewey Decimal Classification System --- Geography & History");
    add("901","Dewey Decimal Classification System --- Geography & History --- Geography & History --- Philosophy & theory");
    add("902","Dewey Decimal Classification System --- Geography & History --- Geography & History --- Miscellany");
    add("903","Dewey Decimal Classification System --- Geography & History --- Geography & History --- Dictionaries & encyclopedias");
    add("904","Dewey Decimal Classification System --- Geography & History --- Geography & History --- Collected accounts of events");
    add("905","Dewey Decimal Classification System --- Geography & History --- Geography & History --- Serial publications");
    add("906","Dewey Decimal Classification System --- Geography & History --- Geography & History --- Organizations & management");
    add("907","Dewey Decimal Classification System --- Geography & History --- Geography & History --- Education, research, related topics");
    add("908","Dewey Decimal Classification System --- Geography & History --- Geography & History --- With respect to kinds of persons");
    add("909","Dewey Decimal Classification System --- Geography & History --- Geography & History --- World history");
    add("910","Dewey Decimal Classification System --- Geography & History --- Geography --- Travel");
    add("911","Dewey Decimal Classification System --- Geography & History --- Geography --- Geography, Historical");
    add("912","Dewey Decimal Classification System --- Geography & History --- Geography --- Cartography, Graphic representations of earth & Maps");
    add("913","Dewey Decimal Classification System --- Geography & History --- Geography --- Ancient world");
    add("914","Dewey Decimal Classification System --- Geography & History --- Geography --- Europe");
    add("915","Dewey Decimal Classification System --- Geography & History --- Geography --- Asia");
    add("916","Dewey Decimal Classification System --- Geography & History --- Geography --- Africa");
    add("917","Dewey Decimal Classification System --- Geography & History --- Geography --- North America");
    add("918","Dewey Decimal Classification System --- Geography & History --- Geography --- South America");
    add("919","Dewey Decimal Classification System --- Geography & History --- Geography --- Other areas");
    add("920","Dewey Decimal Classification System --- Geography & History --- Biography, Genealogy & Insignia");
    add("929","Dewey Decimal Classification System --- Geography & History --- Biography, Genealogy & Insignia --- Genealogy, Insignia and Names"); 
    add("930","Dewey Decimal Classification System --- Geography & History --- History of the Ancient world");
    add("931","Dewey Decimal Classification System --- Geography & History --- History of the Ancient world --- China,");
    add("932","Dewey Decimal Classification System --- Geography & History --- History of the Ancient world --- Egypt,");
    add("933","Dewey Decimal Classification System --- Geography & History --- History of the Ancient world --- Palestine,");
    add("934","Dewey Decimal Classification System --- Geography & History --- History of the Ancient world --- India,");
    add("935","Dewey Decimal Classification System --- Geography & History --- History of the Ancient world --- Mesopotamia & Iranian Plateau");
    add("936","Dewey Decimal Classification System --- Geography & History --- History of the Ancient world --- Europe north & west of Italy");
    add("937","Dewey Decimal Classification System --- Geography & History --- History of the Ancient world --- Italy & adjacent territories");
    add("938","Dewey Decimal Classification System --- Geography & History --- History of the Ancient world --- Greece");
    add("939","Dewey Decimal Classification System --- Geography & History --- History of the Ancient world --- Other parts of ancient world");
    add("940","Dewey Decimal Classification System --- Geography & History --- Europe");
    add("941","Dewey Decimal Classification System --- Geography & History --- Europe --- British Isles,");
    add("942","Dewey Decimal Classification System --- Geography & History --- Europe --- England & Wales,");
    add("943","Dewey Decimal Classification System --- Geography & History --- Europe --- Central Europe & Germany");
    add("944","Dewey Decimal Classification System --- Geography & History --- Europe --- France & Monaco");
    add("945","Dewey Decimal Classification System --- Geography & History --- Europe --- Italian Peninsula");
    add("946","Dewey Decimal Classification System --- Geography & History --- Europe --- Iberian Peninsula");
    add("947","Dewey Decimal Classification System --- Geography & History --- Europe --- Eastern Europe & Soviet Union");
    add("948","Dewey Decimal Classification System --- Geography & History --- Europe --- Northern Europe & Scandinavia");
    add("949","Dewey Decimal Classification System --- Geography & History --- Europe --- Other parts of Europe");
    add("950","Dewey Decimal Classification System --- Geography & History --- Asia & Far East");
    add("951","Dewey Decimal Classification System --- Geography & History --- Asia & Far East --- China");
    add("952","Dewey Decimal Classification System --- Geography & History --- Asia & Far East --- Japan");
    add("953","Dewey Decimal Classification System --- Geography & History --- Arabian Peninsula");
    add("954","Dewey Decimal Classification System --- Geography & History --- Asia & Far East --- India & South Asia");
    add("955","Dewey Decimal Classification System --- Geography & History --- Asia & Far East --- Iran");
    add("956","Dewey Decimal Classification System --- Geography & History --- Asia & Far East --- Middle East & Near East");
    add("957","Dewey Decimal Classification System --- Geography & History --- Asia & Far East --- Asiatic Russia & Siberia");
    add("958","Dewey Decimal Classification System --- Geography & History --- Asia & Far East --- Central Asia");
    add("959","Dewey Decimal Classification System --- Geography & History --- Asia & Far East --- Southeast Asia");
    add("960","Dewey Decimal Classification System --- Geography & History --- Africa & Libya");
    add("961","Dewey Decimal Classification System --- Geography & History --- Africa & Libya --- Tunisia");
    add("962","Dewey Decimal Classification System --- Geography & History --- Africa & Libya --- Egypt & Sudan");
    add("963","Dewey Decimal Classification System --- Geography & History --- Africa & Libya --- Ethiopia");
    add("964","Dewey Decimal Classification System --- Geography & History --- Africa & Libya --- Canary Islands & Morocco");
    add("965","Dewey Decimal Classification System --- Geography & History --- Africa & Libya --- Algeria");
    add("966","Dewey Decimal Classification System --- Geography & History --- Africa & Libya --- West Africa");
    add("967","Dewey Decimal Classification System --- Geography & History --- Africa & Libya --- Central Africa");
    add("968","Dewey Decimal Classification System --- Geography & History --- Africa & Libya --- Southern Africa");
    add("969","Dewey Decimal Classification System --- Geography & History --- Africa & Libya --- South Indian Ocean islands");
    add("970","Dewey Decimal Classification System --- Geography & History --- North America");
    add("971","Dewey Decimal Classification System --- Geography & History --- North America --- Canada");
    add("972","Dewey Decimal Classification System --- Geography & History --- North America --- Mexico & Middle America");
    add("973","Dewey Decimal Classification System --- Geography & History --- North America --- United States");
    add("974","Dewey Decimal Classification System --- Geography & History --- North America --- United States, Northeastern");
    add("975","Dewey Decimal Classification System --- Geography & History --- North America --- United States, Southeastern");
    add("976","Dewey Decimal Classification System --- Geography & History --- North America --- United States, South central");
    add("977","Dewey Decimal Classification System --- Geography & History --- North America --- United States, North central");
    add("978","Dewey Decimal Classification System --- Geography & History --- North America --- United States, Western");
    add("979","Dewey Decimal Classification System --- Geography & History --- North America --- Great Basin & Pacific Slope");
    add("980","Dewey Decimal Classification System --- Geography & History --- South America");
    add("981","Dewey Decimal Classification System --- Geography & History --- South America --- Brazil");
    add("982","Dewey Decimal Classification System --- Geography & History --- South America --- Argentina");
    add("983","Dewey Decimal Classification System --- Geography & History --- South America --- Chile");
    add("984","Dewey Decimal Classification System --- Geography & History --- South America --- Bolivia");
    add("985","Dewey Decimal Classification System --- Geography & History --- South America --- Peru");
    add("986","Dewey Decimal Classification System --- Geography & History --- South America --- Colombia & Ecuador");
    add("987","Dewey Decimal Classification System --- Geography & History --- South America --- Venezuela");
    add("988","Dewey Decimal Classification System --- Geography & History --- South America --- Guiana");
    add("989","Dewey Decimal Classification System --- Geography & History --- South America --- Paraguay & Uruguay");
    add("990","Dewey Decimal Classification System --- Geography & History --- Other areas");
    add("993","Dewey Decimal Classification System --- Geography & History --- Other areas --- New Zealand");
    add("994","Dewey Decimal Classification System --- Geography & History --- Other areas --- Australia");
    add("995","Dewey Decimal Classification System --- Geography & History --- Other areas --- Melanesia & New Guinea");
    add("996","Dewey Decimal Classification System --- Geography & History --- Other areas --- Polynesia");
    add("997","Dewey Decimal Classification System --- Geography & History --- Other areas --- Atlantic Ocean islands");
    add("998","Dewey Decimal Classification System --- Geography & History --- Other areas --- Antarctica & Arctic islands");
    add("999","Dewey Decimal Classification System --- Geography & History --- Other areas --- Extraterrestrial worlds");
  }
  /** */
  public Classification getClassificationFor(String string) {
    return root.getClassificationFor(string);
  }


  /** Returns the name of the ClassificationSystem*/
  public String getName() { return name; };

  /** 
   * Returns an enumeration of all top-level Classifications 
   * (or all Classifications if this is a non-heirarchical 
   * ClassificationSystem) 
   */
  public Enumeration getClassifications() {return root.getSubClassifications();};
 
  /**
   * Parse a string containing one or more Classifications and
   * return an Enumeration of them.
   */
  public Enumeration  parse(String rawDesc) {
    Vector vec = new Vector();
    StringBuffer tmp = new StringBuffer();
    for(int i = 0; i <rawDesc.length();i++) {
      if (Character.isDigit((char)i) || i == '.') {
	tmp.append(i);
      } else {
	if (tmp.length() != 0)
	  vec.add(getClassificationFor(tmp.toString()));
	tmp.delete(0,tmp.length());
      }
    }      
    return vec.elements();

  };

  public static void main(String args[]) throws IOException
  {
    DeweyDecimalClassificationSystem system = 
      new DeweyDecimalClassificationSystem();
  }

}
